@@ -3,27 +3,29 @@ mod insert;
 mod parquet_buffer;
 mod query;
 
-use crate::enum_args::{compression_from_str, EncodingArgument, COMPRESSION_VARIANTS};
+use crate::enum_args::{
+    column_encoding_from_str, compression_from_str, EncodingArgument, COMPRESSION_VARIANTS,
+};
 use anyhow::{bail, Error};
 use odbc_api::{escape_attribute_value, Connection, Environment};
-use parquet::basic::Compression;
+use parquet::basic::{Compression, Encoding};
 use std::path::PathBuf;
 use structopt::StructOpt;
 
+#[cfg(target_os = "windows")]
+use odbc_api::DriverCompleteOption;
 #[cfg(target_os = "windows")]
 use winit::{
     event_loop::EventLoop,
     window::{Window, WindowBuilder},
 };
-#[cfg(target_os = "windows")]
-use odbc_api::DriverCompleteOption;
 
 /// Query an ODBC data source at store the result in a Parquet file.
 #[derive(StructOpt)]
 struct Cli {
     /// Only print errors to standard error stream. Supresses warnings and all other log levels
     /// independent of the verbose mode.
-    #[structopt(short = "q",long)]
+    #[structopt(short = "q", long)]
     quiet: bool,
     /// Verbose mode (-v, -vv, -vvv, etc)
     ///
@@ -135,6 +137,11 @@ pub struct QueryOpt {
     /// been introduced in an effort to increase the compatibility of the output with Apache Spark.
     #[structopt(long)]
     prefer_varbinary: bool,
+    /// Specify the fallback encoding of the parquet output column. You can parse mutliple values
+    /// in format `COLUMN:ENCODING`. `ENCODING` must be one of: `plain`, `bit-packed`,
+    /// `delta-binary-packed`, `delta-byte-array`, `delta-length-byte-array` or `rle`.
+    #[structopt(long, multiple=true, parse(try_from_str=column_encoding_from_str))]
+    parquet_column_encoding: Vec<(String, Encoding)>,
     /// Name of the output parquet file.
     output: PathBuf,
     /// Query executed against the ODBC data source. Question marks (`?`) can be used as
@@ -192,7 +199,7 @@ fn main() -> Result<(), Error> {
     stderrlog::new()
         .module(module_path!())
         .module("odbc_api")
-        .quiet(false) // Even if `opt.quiet` is true, we still want to print errors 
+        .quiet(false) // Even if `opt.quiet` is true, we still want to print errors
         .verbosity(verbose)
         .timestamp(stderrlog::Timestamp::Second)
         .init()
@@ -280,6 +287,7 @@ fn open_connection<'e>(
     Ok(conn)
 }
 
+/// Used as a parent window for the prompt by the ODBC driver manager on windows systems.
 #[cfg(target_os = "windows")]
 fn message_only_window() -> Result<Window, Error> {
     let window = WindowBuilder::new()
